#========================================================================================
# package      DE_EPAGES::Core::API::Program::mongodb
# state        public
#----------------------------------------------------------------------------------------
# description  Program interface for mongodb (http://www.mongodb.org/)
#========================================================================================
package DE_EPAGES::Core::API::Program::mongodb;
use base DE_EPAGES::Core::API::Program::Base;

use strict;
use Config;

use DE_EPAGES::Core::API::Error qw( Error );
use DE_EPAGES::Core::API::SystemCommand qw( SystemCommand );
use DE_EPAGES::Core::API::Program::Tools qw( FindProgramFile );
use DE_EPAGES::Core::API::PerlTools qw( UsePackage );

#ERRORDEFINITION
sub ErrorDefinition () {
    return {
        'NoVersionFound' => 'Can\'t get version from command #Command',
    }
}
#ERRORDEFINITION END

sub command {

    return 'mongo' if $^O eq 'linux'; # linux

    my $Command = FindProgramFile('mongodb-*/bin/mongo.exe'); # windows
    return $Command ? $Command : 'mongo.exe';
}

sub version {
    my $self = shift;

    my $Command = $self->command;
    my $Output = SystemCommand( "\"$Command\" --version", { 'Capture' => 1 } );
    if( $Output =~ /MongoDB shell version:? (\S+)/ ) {
        my $Version = $1;
         $Version =~ s,^v,,;
        return $Version;
    }
    else {
        Error('NoVersionFound', { Command => $Command });
    }
}

sub winpkg {
    return 'mongodb.zip';
}

sub installCmd {
    return 'unzip -qq "%s" -d "%s"';
}

sub preInstall {
    UsePackage('DE_EPAGES::Installer::API::EpagesJ');
    DE_EPAGES::Installer::API::EpagesJ::AddMongoDBService(undef, undef, {remove => 1});
}

sub postInstall {
    UsePackage('DE_EPAGES::Installer::API::Service');
    UsePackage('DE_EPAGES::Installer::API::EpagesJ');

    DE_EPAGES::Installer::API::EpagesJ::AddMongoDBService();
    DE_EPAGES::Installer::API::Service::StartService('mongodb');
}

1;
