#========================================================================================
# package      DE_EPAGES::Mollie::UI::PaymentMethodMollie
# base         DE_EPAGES::Payment::UI::PaymentMethod
# state        private
#----------------------------------------------------------------------------------------
# description  UI Controller for payment method
#========================================================================================
package DE_EPAGES::Mollie::UI::PaymentMethodMollie;
use base DE_EPAGES::Payment::UI::PaymentMethod;


use DE_EPAGES::Core::API::Error qw ( ExistsError GetError );
use DE_EPAGES::ExternalPayment::API::Log qw ( LogPayment );
use DE_EPAGES::Mollie::API::MolliePayment;
use DE_EPAGES::Object::API::Table::Language qw ( GetInfoLanguage );

use strict;



#========================================================================================
# function     ViewSettings
# state        public
#----------------------------------------------------------------------------------------
# syntax       ViewSettings( $Servlet );
#----------------------------------------------------------------------------------------
# description  UI Controller to view settings on the MBO settings page.
#----------------------------------------------------------------------------------------
# input        $Servlet | Servlet | DE_EPAGES::Presentation::Servlet::BasePermission
#========================================================================================
sub ViewSettings {
    my $self = shift;
    my ($Servlet) = @_;

    my $PaymentMethod = $Servlet->object();
    my $PaymentType = $PaymentMethod->get('PaymentType');
    my $Shop = $PaymentMethod->getSite();

    $Servlet->vars('IsUsable', $PaymentType->isUsable($Shop));

    return;
}



#========================================================================================
# function     SaveSettings
# state        public
#----------------------------------------------------------------------------------------
# syntax       SaveSettings( $Servlet );
#----------------------------------------------------------------------------------------
# description  UI Controller to save settings on the MBO settings page.
#----------------------------------------------------------------------------------------
# input        $Servlet | Servlet | DE_EPAGES::Presentation::Servlet::BasePermission
#========================================================================================
sub SaveSettings {
    my $self = shift;
    my ($Servlet) = @_;

    my $PaymentMethod = $Servlet->object();
    my $Form = $Servlet->form();

    my $MolliePayment = DE_EPAGES::Mollie::API::MolliePayment->new();
    my $Locale = GetInfoLanguage( $Servlet->languageID )->{'DefaultLocaleID'};

    eval {
        $Form->form($PaymentMethod, 'MollieSettings');

        my $Apikey = $Form->value('APIToken');
        $MolliePayment->listPayments($PaymentMethod->get('Site'), $Locale, $Apikey);
    };

    if ( ExistsError() ) {
        my $Error = GetError();
        LogPayment('Mollie','CheckMollieConnection' , $Error->longMessage(), 'Error');
        $Form->executeFormError( {
                'Name'       => 'MollieSettings',
                'Reason'     => 'apiTokenInvalid'
            }
        );
    }

    $self->Save($Servlet);

    return;
}


1;