package DE_EPAGES::Order::t::CartResource;
use base DE_EPAGES::Shop::API::Test;

use DE_EPAGES::Object::API::XML::ObjectImportHandler qw( ImportObjects );
use DE_EPAGES::Order::API::Resource::CartCollection;
use URI::QueryParam;
use URI::Escape;
use URI;
use Test::More;
use Test::Exception;

use strict;



## no critic qw( ProhibitMagicNumbers )

sub test {
    my $self = shift;

    $self->test_GetCarts();

    #place her later on the delete and put test
    done_testing();
}

sub test_GetCarts {
    my $self = shift;

    my $Resource = DE_EPAGES::Order::API::Resource::CartCollection->new;

    my $Request1 = HTTP::Request->new(GET => 'http://www.example.com/api/carts/?hasAddressData=false');
    ok($Resource->match($Request1), 'url1 matches');

    my $Request2 = HTTP::Request->new(GET => 'http://www.example.com/api/carts/?hasAddressData=true');
    ok($Resource->match($Request2), 'url2 matches');

    my $hQuery;
    $hQuery->{ 'includeTax' } = ['false'];
    $hQuery->{ 'hasAddressData' } = ['false'];

    my $hData = $Resource->get( $self->shop, $hQuery );
    ok $hData, "Get carts returns a response";
    is($hData->{'results'}, 1, 'Number of returned carts without address data is 1');
    is($hData->{'items'}[0]->{'shippingAddress'},undef,'ShippingAddress is not set');
    is($hData->{'items'}[0]->{'billingAddress'},undef,'BillingAddress is not set');


    $hQuery->{ 'hasAddressData' } = ['true'];
    $hData = $Resource->get( $self->shop, $hQuery );

    ok $hData, "Get carts returns a response";
    is($hData->{'results'}, 1, 'Number of returned carts with address data is 1');
    is($hData->{'items'}[0]->{'shippingAddress'}->{'street'},'Musterweg 42','ShippingAddress street is set');
    is($hData->{'items'}[0]->{'billingAddress'}->{'emailAddress'},'hund@epages.de','Billing email address is set');

}

sub getCartRef1 {
    return {
        minimumCart => {
            'status' => 'false',
            'amount' => {
                'currency' => 'GBP',
                'taxType' => 'GROSS',
                'amount' => '200',
                'formatted' => "\x{a3}200.00",
            },
            'code' => 'SumPayment'
        },
        billingAddress => undef,
        shippingAddress => undef,
        lineItemContainer => {
            grandTotal => {
                currency => 'GBP',
                taxType => 'GROSS',
                amount => '79.95',
                formatted => "\x{a3}79.95",
            },
            totalBeforeTax => {
                currency => 'GBP',
                taxType => 'NET',
                amount => '68.92',
                formatted => "\x{a3}68.92",
            },
            totalTax => {
                currency => 'GBP',
                taxType => 'NONE',
                amount => '12.77',
                formatted => "\x{a3}12.77",
            },
            lineItemsSubTotal => {
                currency => 'GBP',
                taxType => 'GROSS',
                amount => '72.95',
                formatted => "\x{a3}72.95",
            },
            shippingPrice => {
                currency => 'GBP',
                taxType => 'GROSS',
                amount => '7',
                formatted => "\x{a3}7.00",
            },
            otherLineItems => [],
            couponLineItem => undef,
            productLineItems => [
                {
                    lineItemId => '53AD3774-B3DC-155B-3E97-AC1432AA8AC2',
                    productId => '53AAD424-2BA4-9660-8182-AC1432AA1F2B',
                    energyLabelSourceFile => undef,
                    energyLabelsString => undef,
                    energyLabelsMaxEfficiencyString => undef,
                    sku => 'lt_0401107001',
                    name => 'Leatherman Tool Survival',
                    variationString => undef,
                    essentialFeatures => 'test product petrol',
                    quantity => {
                        unit => 'piece(s)',
                        amount => '1'
                    },
                    singleItemPrice => {
                        currency => 'GBP',
                        taxType => 'GROSS',
                        amount => '72.95',
                        formatted => "\x{a3}72.95",
                    },
                    lineItemPrice => {
                        currency => 'GBP',
                        taxType => 'GROSS',
                        amount => '72.95',
                        formatted => "\x{a3}72.95",
                    },
                    lineItemCouponDiscount => undef,
                    taxClass => {
                        taxClassId => '576D1026-DD10-DBC1-3E02-AC143C2B8ADE',
                        name => 'custom',
                        percentage => '16',
                    },
                    images => [],
                    deliveryWeight => undef,
                    links => [
                        {
                            rel => 'product',
                            href => 'https://test-domain/api/products/53AAD424-2BA4-9660-8182-AC1432AA1F2B'
                        },
                        {
                            rel => 'taxClass',
                            href => 'https://test-domain/api/tax-classes/576D1026-DD10-DBC1-3E02-AC143C2B8ADE'
                        },
                    ],
                },
            ],
        },
        'shippingData' => {
            'shippingMethod' => {
                'name' => 'Post',
            },
            'price' => {
                'currency' => 'GBP',
                'taxType' => 'GROSS',
                'amount' => '7',
                'formatted' => "\x{a3}7.00"
            },
            'taxes' => [
                {
                    'taxClass' => {
                        'taxClassId' => '576D1026-DD10-DBC1-3E02-AC143C2B8ADE',
                        'name' => 'custom',
                        'percentage' => 16
                    },
                    'price' => {
                        'currency' => 'GBP',
                        'taxType' => 'NONE',
                        'amount' => '1.12',
                        'formatted' => "\x{a3}1.12"
                    }
                }
            ]
        },
        'paymentData' => {
            'paymentMethod' => {
                'name' => 'CashInAdvance',
                'providerName' => undef,
                'additionalData' => undef
            },
            'transactionId' => undef,
            'price' => {
                'currency' => 'GBP',
                'taxType' => 'GROSS',
                'amount' => '0',
                'formatted' => "\x{a3}0.00"
            },
            'status' => undef,
            'taxes' => [
                {
                    'taxClass' => {
                        'taxClassId' => '576D1026-DD10-DBC1-3E02-AC143C2B8ADE',
                        'name' => 'custom',
                        'percentage' => '16'
                    },
                    'price' => {
                        'currency' => 'GBP',
                        'taxType' => 'NONE',
                        'amount' => '0',
                        'formatted' => "\x{a3}0.00"
                    }
                }]
        },
        'links' => [],
    };
}

sub getCartRef2 {
    return {
        minimumCart => {
            'status' => 'true',
            'amount' => undef,
            'code' => 'SumPayment'
        },
        billingAddress => {
            country => 'DE',
            zipCode => '08157',
            firstName => 'Gaby',
            salutation => undef,
            vatId => undef,
            street => 'Musterweg 42',
            state => undef,
            city => 'Musterhausen',
            title => undef,
            lastName => 'Mustermann',
            streetDetails => undef,
            birthday => '1970-08-18',
            company => undef,
            emailAddress => 'hund@epages.de',
            bankAccountNumber => undef,
            department => undef,
            fiscalCode => undef,
            displayName => undef,
            middleName => undef,
            businessPhoneNumber => undef,
            jobTitle => undef,
            websiteUrl => undef,
            bankSortCode => undef,
            bankAccountHolder => undef,
            doorCode => undef,
            phoneNumber => undef,
            gender => undef,
            mobilePhoneNumber => undef,
            privateEmailAddress => undef,
            businessEmailAddress => undef,
            privatePhoneNumber => undef,
            bankName => undef,
            addressExtension => undef,
            faxNumber => undef,
        },
        shippingAddress => {
            country => 'DE',
            zipCode => '08157',
            firstName => 'Fred',
            salutation => undef,
            vatId => undef,
            street => 'Musterweg 42',
            state => undef,
            city => 'Musterhausen',
            title => undef,
            lastName => 'Mustermann',
            streetDetails => undef,
            birthday => undef,
            company => undef,
            emailAddress => undef,
            bankAccountNumber => undef,
            department => undef,
            fiscalCode => undef,
            displayName => undef,
            middleName => undef,
            businessPhoneNumber => undef,
            jobTitle => undef,
            websiteUrl => undef,
            bankSortCode => undef,
            bankAccountHolder => undef,
            doorCode => undef,
            phoneNumber => undef,
            gender => undef,
            mobilePhoneNumber => undef,
            privateEmailAddress => undef,
            businessEmailAddress => undef,
            privatePhoneNumber => undef,
            bankName => undef,
            addressExtension => undef,
            faxNumber => undef,
        },
        lineItemContainer => {
            grandTotal => {
                currency => 'EUR',
                taxType => 'GROSS',
                amount => '34.35',
                formatted => "34,35 \x{20ac}",
            },
            totalBeforeTax => {
                currency => 'EUR',
                taxType => 'NET',
                amount => '29.92',
                formatted => "29.92 \x{20ac}",
            },
            totalTax => {
                currency => 'EUR',
                taxType => 'NONE',
                amount => '5.48',
                formatted => "5,48 \x{20ac}",
            },
            lineItemsSubTotal => {
                currency => 'EUR',
                taxType => 'GROSS',
                amount => '26.9',
                formatted => "26,90 \x{20ac}",
            },
            shippingPrice => {
                currency => 'EUR',
                taxType => 'GROSS',
                amount => '7.45',
                formatted => "7,45 \x{20ac}",
            },
            otherLineItems => [],
            couponLineItem => undef,
            productLineItems => [
                {
                    lineItemId => '53AD3774-8BE0-3028-D733-AC1432AA8A71',
                    productId => '53AA9617-0C07-5434-801A-AC1432AA7911',
                    sku => 'cg_0101004270',
                    name => 'Campingaz CV270 Ventilgaskartusche',
                    variationString => undef,
                    energyLabelSourceFile => undef,
                    energyLabelsString => 'B',
                    energyLabelsMaxEfficiencyString => 'A+',
                    essentialFeatures => 'test produkt',
                    quantity => {
                        unit => "St\x{fc}ck",
                        amount => '1'
                    },
                    singleItemPrice => {
                        currency => 'EUR',
                        taxType => 'GROSS',
                        amount => '3.95',
                        formatted => "3,95 \x{20ac}",
                    },
                    lineItemPrice => {
                        currency => 'EUR',
                        taxType => 'GROSS',
                        amount => '3.95',
                        formatted => "3,95 \x{20ac}",
                    },
                    lineItemCouponDiscount => undef,
                    taxClass => {
                        taxClassId => '576D1026-DD10-DBC1-3E02-AC143C2B8ADE',
                        name => 'custom',
                        percentage => '16',
                    },
                    images => [],
                    deliveryWeight => undef,
                    links => [
                        {
                            rel => 'product',
                            href => 'https://test-domain/api/products/53AA9617-0C07-5434-801A-AC1432AA7911'
                        },
                        {
                            rel => 'taxClass',
                            href => 'https://test-domain/api/tax-classes/576D1026-DD10-DBC1-3E02-AC143C2B8ADE'
                        },
                    ],
                },
                {
                    lineItemId => '53AD3774-0D65-3199-0752-AC1432AA8AAC',
                    productId => '53AA962B-1F09-B778-E3AF-AC1432AA7986',
                    sku => 'cg_0100504001',
                    name => 'Campingaz Twister 270',
                    variationString => undef,
                    energyLabelSourceFile => undef,
                    energyLabelsString => undef,
                    energyLabelsMaxEfficiencyString => undef,
                    essentialFeatures => 'test produkt',
                    quantity => {
                        unit => "St\x{fc}ck",
                        amount => '1'
                    },
                    singleItemPrice => {
                        currency => 'EUR',
                        taxType => 'GROSS',
                        amount => '22.95',
                        formatted => "22,95 \x{20ac}",
                    },
                    lineItemPrice => {
                        currency => 'EUR',
                        taxType => 'GROSS',
                        amount => '22.95',
                        formatted => "22,95 \x{20ac}",
                    },
                    lineItemCouponDiscount => undef,
                    taxClass => {
                        taxClassId => '576D1026-DD10-DBC1-3E02-AC143C2B8ADE',
                        name => 'custom',
                        percentage => '16',
                    },
                    images => [],
                    deliveryWeight => undef,
                    links => [
                        {
                            rel => 'product',
                            href => 'https://test-domain/api/products/53AA962B-1F09-B778-E3AF-AC1432AA7986'
                        },
                        {
                            rel => 'taxClass',
                            href => 'https://test-domain/api/tax-classes/576D1026-DD10-DBC1-3E02-AC143C2B8ADE'
                        },
                    ],
                },
            ],
        },
        'shippingData' => {
            'shippingMethod' => {
                'name' => 'Post',
            },
            'price' => {
                'currency' => 'EUR',
                'taxType' => 'GROSS',
                'amount' => '7.45',
                'formatted' => "7,45 \x{20ac}"
            },
            'taxes' => [
                {
                    'taxClass' => {
                        'taxClassId' => '576D1026-DD10-DBC1-3E02-AC143C2B8ADE',
                        'name' => 'custom',
                        'percentage' => 19
                    },
                    'price' => {
                        'currency' => 'EUR',
                        'taxType' => 'NONE',
                        'amount' => '1.16',
                        'formatted' => "1,16 \x{20ac}"
                    }
                }
            ]
        },
        'paymentData' => {
            'paymentMethod' => {
                'name' => 'CashOnDelivery',
                'providerName' => undef,
                'additionalData' => undef
            },
            'transactionId' => undef,
            'price' => {
                'currency' => 'EUR',
                'taxType' => 'GROSS',
                'amount' => '0',
                'formatted' => "0,00 \x{20ac}"
            },
            'status' => undef,
            'taxes' => [
                {
                    'taxClass' => {
                        'taxClassId' => '576D1026-DD10-DBC1-3E02-AC143C2B8ADE',
                        'name' => 'custom',
                        'percentage' => '19'
                    },
                    'price' => {
                        'currency' => 'EUR',
                        'taxType' => 'NONE',
                        'amount' => '0',
                        'formatted' => "0,00 \x{20ac}"
                    }
                }
            ]
        },
        'links' => [],
    };
}

sub init {
    my $self = shift;

    $self->SUPER::init;
    die 'Shop alias is not TestShop' unless $self->shop->alias eq 'TestShop';
    $self->shop->set({
        DomainName => 'test-domain',
        HasSSLCertificate => 1,
        MinOrderAmounts => [{ 'CurrencyID'=>'GBP', 'Value'=>'200' }],
        MinOrderSubTotalAttributeName => 'GrandTotal',
    });

    note 'importing cartTest.xml';
    ImportObjects('cartTest.xml', $self->shop->pathString);
}

__PACKAGE__->runScript;
